@@ -15,7 +15,7 @@ sub funcall {
 
 	my (@self, $a, $x) = shift;
 
-	1 / ( $a * sqrt($self->{PI}) ) * exp(- ($x/$a) * ($x/$a));
+	return (1 / ( $a * sqrt($self->{PI}) ) * exp(- ($x/$a) * ($x/$a)));
 }
 
 1;
